@@ -1,4 +1,4 @@
-# Copyright (C) 2013-2015  Ruby-GNOME2 Project Team
+# Copyright (C) 2013-2018  Ruby-GNOME2 Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,19 +18,6 @@ require "English"
 
 require "gobject-introspection"
 
-base_dir = Pathname.new(__FILE__).dirname.dirname.expand_path
-vendor_dir = base_dir + "vendor" + "local"
-vendor_bin_dir = vendor_dir + "bin"
-GLib.prepend_dll_path(vendor_bin_dir)
-vendor_girepository_dir = vendor_dir + "lib" + "girepository-1.0"
-GObjectIntrospection.prepend_typelib_path(vendor_girepository_dir)
-
-if vendor_dir.exist?
-  require "cairo"
-  require "gdk_pixbuf2"
-  require "pango"
-end
-
 module Gst
   LOG_DOMAIN = "GStreamer"
   GLib::Log.set_log_domain(LOG_DOMAIN)
@@ -122,12 +109,7 @@ module Gst
     end
 
     def require_extension
-      begin
-        major, minor, _ = RUBY_VERSION.split(/\./)
-        require "#{major}.#{minor}/gstreamer.so"
-      rescue LoadError
-        require "gstreamer.so"
-      end
+      require "gstreamer.so"
     end
 
     def require_libraries
