@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2016  Ruby-GNOME2 Project Team
+# Copyright (C) 2014-2019  Ruby-GNOME2 Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -69,20 +69,17 @@ module Gtk
     end
 
     def require_extension
-      begin
-        major, minor, _ = RUBY_VERSION.split(/\./)
-        require "#{major}.#{minor}/gtk3.so"
-      rescue LoadError
-        require "gtk3.so"
-      end
+      require "gtk3.so"
     end
 
     def require_libraries
       require "gtk3/gdk-drag-context"
+      require "gtk3/gdk-screen"
 
       require "gtk3/about-dialog"
       require "gtk3/action"
       require "gtk3/action-group"
+      require "gtk3/application"
       require "gtk3/binding-set"
       require "gtk3/border"
       require "gtk3/box"
@@ -98,6 +95,7 @@ module Gtk
       require "gtk3/container"
       require "gtk3/css-provider"
       require "gtk3/dialog"
+      require "gtk3/entry"
       require "gtk3/entry-buffer"
       require "gtk3/file-chooser-dialog"
       require "gtk3/font-chooser-dialog"
