@@ -25,25 +25,25 @@ class TestGtkIconTheme < Test::Unit::TestCase
     end
 
     def test_context
-      assert_operator(@theme.icons("Actions"), :include?, "find")
+      assert_operator(@theme.icons("Actions"), :include?, "edit-find")
     end
   end
 
   sub_test_case "#lookup_icon" do
     sub_test_case "icon" do
       test "String" do
-        assert_not_nil(@theme.lookup_icon("search",
+        assert_not_nil(@theme.lookup_icon("edit-find",
                                           16, :generic_fallback))
       end
 
       test "Symbol" do
-        assert_not_nil(@theme.lookup_icon("search",
+        assert_not_nil(@theme.lookup_icon("edit-find",
                                           16, :generic_fallback))
       end
 
       test "Gio::Icon" do
-        icon = Gio::ThemedIcon.new("search")
-        assert_not_nil(@theme.lookup_icon(icon, 16, :generic_fallback))
+        icon = Gio::ThemedIcon.new("edit-find")
+        assert_not_nil(@theme.lookup_icon(icon, 16))
       end
     end
   end
